@@ -1,7 +1,6 @@
 package cmd_test
 
 import (
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"testing"
@@ -11,12 +10,13 @@ import (
 
 func TestUseExecutesProjectTemplate(t *testing.T) {
 	t.SkipNow()
-	tmpDirPath, err := ioutil.TempDir("", "template-test")
+	tmpDirPath, err := os.MkdirTemp("", "template-test")
 	if err != nil {
-		t.Fatalf("ioutil.TempDir() got error -> %v", err)
-	} else {
-		//defer os.RemoveAll(tmpDirPath)
+		t.Fatalf("os.MkdirTemp() got error -> %v", err)
 	}
+	// else {
+	// 	defer os.RemoveAll(tmpDirPath)
+	// }
 
 	if err := os.MkdirAll(filepath.Join(tmpDirPath, "input", "{{Name}}", "{{Date}}"), 0744); err != nil {
 		t.Fatalf("os.MkdirAll should have created template directories -> got error %v", err)
